[−][src]Trait wascc_codec::capabilities::Dispatcher
The dispatcher is used by a native capability provider to send commands to an actor module, expecting a result containing a byte array in return
Required methods
fn dispatch(
&self,
actor: &str,
op: &str,
msg: &[u8]
) -> Result<Vec<u8>, Box<dyn Error + Sync + Send>>
&self,
actor: &str,
op: &str,
msg: &[u8]
) -> Result<Vec<u8>, Box<dyn Error + Sync + Send>>